@@ -3,13 +3,13 @@ from banal import ensure_list
 
 class Result(object):
     def __init__(self, data):
+        self.value = data.pop("value", None)
+        if "values" in data:
+            self.values = ensure_list(data.pop("values", []))
+        else:
+            self.values = [self.value]
         self._data = data
 
-    @property
-    def values(self):
-        values = self._data.pop("values", self.value)
-        return ensure_list(values)
-
     def __getattr__(self, name):
         try:
             return self._data[name]
